complete -c rustnet -s i -l interface -d 'Network interface to monitor (use "any" to capture all interfaces)' -r
complete -c rustnet -s r -l refresh-interval -d 'UI refresh interval in milliseconds' -r
complete -c rustnet -s l -l log-level -d 'Set the log level (if not provided, no logging will be enabled)' -r
complete -c rustnet -l json-log -d 'Enable JSON logging of connection events to specified file' -r
complete -c rustnet -l pcap-export -d 'Export captured packets to PCAP file for Wireshark analysis' -r
complete -c rustnet -l pcapng-export -d 'Export captured packets to annotated PCAPNG file for Wireshark analysis' -r
complete -c rustnet -s f -l bpf-filter -d 'BPF filter expression for packet capture (e.g., "tcp port 443", "dst port 80")' -r
complete -c rustnet -l theme -d 'Color theme preset: "muted" (single accent, color reserved for signals) or "classic" (original full-color palette)' -r -f -a "muted\t''
classic\t''"
complete -c rustnet -l geoip-country -d 'Path to GeoLite2-Country.mmdb database. Auto-discovered from: ./resources/geoip2, $XDG_DATA_HOME/rustnet/geoip, ~/.local/share/rustnet/geoip, /usr/share/GeoIP, /usr/local/share/GeoIP, /opt/homebrew/share/GeoIP, /var/lib/GeoIP' -r
complete -c rustnet -l geoip-asn -d 'Path to GeoLite2-ASN.mmdb database (same search paths as --geoip-country)' -r
complete -c rustnet -l geoip-city -d 'Path to GeoLite2-City.mmdb database (same search paths as --geoip-country; superset of Country — provides city name and postal code in addition to country)' -r
complete -c rustnet -l kubernetes -d 'Kubernetes pod/container attribution: "auto" (enable only when running inside a pod), "on" (always), or "off"' -r -f -a "auto\t''
on\t''
off\t''"
complete -c rustnet -l no-localhost -d 'Filter out localhost connections'
complete -c rustnet -l show-localhost -d 'Show localhost connections (overrides default filtering)'
complete -c rustnet -l no-dpi -d 'Disable deep packet inspection'
complete -c rustnet -l no-resolve-dns -d 'Disable reverse DNS resolution for IP addresses (enabled by default; shows hostnames instead of IPs)'
complete -c rustnet -l show-ptr-lookups -d 'Show PTR lookup connections in UI (hidden by default when DNS resolution is enabled)'
complete -c rustnet -l no-color -d 'Disable all colors in the UI (also respects NO_COLOR env var)'
complete -c rustnet -l no-geoip -d 'Disable GeoIP lookups entirely'
complete -c rustnet -l no-sandbox -d 'Disable sandboxing (on Linux, PR_SET_NO_NEW_PRIVS is still set)'
complete -c rustnet -l sandbox-strict -d 'Require full sandbox enforcement or exit'
complete -c rustnet -l no-uid-drop -d 'Keep running as root instead of dropping to SUDO_UID/SUDO_GID (or nobody) after initialization. Keeping root lets the procfs fallback attribute other users\' processes when eBPF is unavailable'
complete -c rustnet -s h -l help -d 'Print help'
complete -c rustnet -s V -l version -d 'Print version'
